@@ -1013,7 +1013,7 @@ Return:
 void build_preArc_threaded ( preArc_array * arc_arr, vertex_hash2 * v_ht, int K_size, int cut_off_len, vector<string> *in_filenames_vt, int thread_num )
 {
 	//create main io thread
-	int read_buf_sz = 102400 * thrd_num;
+	int read_buf_sz = 102400 * thrd_num_s;
 	read_buf0 = new string[read_buf_sz];
 	read_buf1 = new string[read_buf_sz];
 	io_stat0 = 1; //must be one, if io_stat0 =0 ,the io thread will work immediately
@@ -1035,9 +1035,9 @@ void build_preArc_threaded ( preArc_array * arc_arr, vertex_hash2 * v_ht, int K_
 	fprintf ( stderr, "1 io thread initialized.\n" );
 	//create work threads ..
 	//fprintf(stderr,"Creating work threads ...\n");
-	pthread_t threads[thrd_num];
-	unsigned char thrdSignal[thrd_num + 1];
-	PARAMETER paras[thrd_num];
+	pthread_t threads[thrd_num_s];
+	unsigned char thrdSignal[thrd_num_s + 1];
+	PARAMETER paras[thrd_num_s];
 	locks = ( pthread_spinlock_t * ) calloc ( arc_arr->array_sz, sizeof ( pthread_spinlock_t ) );
 
 	//init as unlock stat ..
@@ -1046,7 +1046,7 @@ void build_preArc_threaded ( preArc_array * arc_arr, vertex_hash2 * v_ht, int K_
 		locks[i] = 1;
 	}
 
-	for ( int k = 0; k < thrd_num; k++ )
+	for ( int k = 0; k < thrd_num_s; k++ )
 	{
 		thrdSignal[k + 1] = 0;
 		paras[k].threadID = k;
