@@ -36,16 +36,17 @@
 static int LOAD_GRAPH = 0, BUILD_DBG = 1, BUILD_EDGES = 1, BUILD_PREARCS = 1;
 //static    int run_mode=0;
 
-int call_pregraph_sparse ( int argc, char ** argv );
+extern "C" int call_pregraph_sparse ( int argc, char ** argv );
 static void initenv ( int argc, char ** argv );
 static void parse_args ( vector<string> &in_filenames_vt );
 static void display_pregraph_usage();
 
+/*
 int main ( int argc, char ** argv )
 {
 	fprintf ( stderr, "\nVersion 1.0.3: released on July 13th, 2012\nCompile %s\t%s\n\n", __DATE__, __TIME__ );
 	call_pregraph_sparse ( argc, argv );
-}
+}*/
 
 
 
@@ -73,7 +74,7 @@ Output:
 Return:
     None.
 *************************************************/
-int call_pregraph_sparse ( int argc, char ** argv )
+extern "C" int call_pregraph_sparse ( int argc, char ** argv )
 {
 	time_t all_beg_time, all_end_time;
 	time ( &all_beg_time );
@@ -108,7 +109,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 				}
 
 				hashTableSZ = ( size_t ) GenomeSize / max ( gap - 1, 5 );
-				int read_buf_sz = 102400 * thrd_num;
+				int read_buf_sz = 102400 * thrd_num_s;
 				Init_HT2 ( &ht2, hashTableSZ );
 				//create main io thread
 				read_buf0 = new string[read_buf_sz];
@@ -131,9 +132,9 @@ int call_pregraph_sparse ( int argc, char ** argv )
 
 				fprintf ( stderr, "1 io thread initialized.\n" );
 				//create work threads  for round 1
-				pthread_t threads[thrd_num];
-				unsigned char thrdSignal[thrd_num + 1];
-				PARAMETER paras[thrd_num];
+				pthread_t threads[thrd_num_s];
+				unsigned char thrdSignal[thrd_num_s + 1];
+				PARAMETER paras[thrd_num_s];
 				locks = ( pthread_spinlock_t * ) calloc ( ht2.ht_sz, sizeof ( pthread_spinlock_t ) );
 
 				//initialize the locks  unlock
@@ -144,10 +145,10 @@ int call_pregraph_sparse ( int argc, char ** argv )
 
 				//create threads
 				//fprintf(stderr,"Creating work threads ...\n");
-				bucket_count_total = ( size_t * ) calloc ( thrd_num, sizeof ( size_t ) );
-				edge_cnt_total = ( size_t * ) calloc ( thrd_num, sizeof ( size_t ) );
+				bucket_count_total = ( size_t * ) calloc ( thrd_num_s, sizeof ( size_t ) );
+				edge_cnt_total = ( size_t * ) calloc ( thrd_num_s, sizeof ( size_t ) );
 
-				for ( int k = 0; k < thrd_num; k++ )
+				for ( int k = 0; k < thrd_num_s; k++ )
 				{
 					thrdSignal[k + 1] = 0;
 					paras[k].threadID = k;
@@ -174,7 +175,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 						processed_reads += read_num;
 						sendWorkSignal ( 10, thrdSignal );
 
-						for ( int k1 = 0; k1 < thrd_num; ++k1 )
+						for ( int k1 = 0; k1 < thrd_num_s; ++k1 )
 						{
 							bucket_count += bucket_count_total[k1];
 							bucket_count_total[k1] = 0;
@@ -221,7 +222,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 				time ( &beg_time );
 				edge_cnt = 0;
 				//create main io thread
-				int read_buf_sz = 102400 * thrd_num;
+				int read_buf_sz = 102400 * thrd_num_s;
 				read_buf0 = new string[read_buf_sz];
 				read_buf1 = new string[read_buf_sz];
 				io_stat0 = 1; //must be one, if io_stat0 =0 ,the io thread will work immediately
@@ -242,9 +243,9 @@ int call_pregraph_sparse ( int argc, char ** argv )
 
 				fprintf ( stderr, "1 io thread initialized.\n" );
 				//create work threads  for round 2
-				pthread_t threads[thrd_num];
-				unsigned char thrdSignal[thrd_num + 1];
-				PARAMETER paras[thrd_num];
+				pthread_t threads[thrd_num_s];
+				unsigned char thrdSignal[thrd_num_s + 1];
+				PARAMETER paras[thrd_num_s];
 				locks = ( pthread_spinlock_t * ) calloc ( ht2.ht_sz, sizeof ( pthread_spinlock_t ) );
 
 				//initialize locks unlock
@@ -255,10 +256,10 @@ int call_pregraph_sparse ( int argc, char ** argv )
 
 				//create threads
 				//fprintf(stderr,"Creating work threads ...\n");
-				bucket_count_total = ( size_t * ) calloc ( thrd_num, sizeof ( size_t ) );
-				edge_cnt_total = ( size_t * ) calloc ( thrd_num, sizeof ( size_t ) );
+				bucket_count_total = ( size_t * ) calloc ( thrd_num_s, sizeof ( size_t ) );
+				edge_cnt_total = ( size_t * ) calloc ( thrd_num_s, sizeof ( size_t ) );
 
-				for ( int k = 0; k < thrd_num; k++ )
+				for ( int k = 0; k < thrd_num_s; k++ )
 				{
 					thrdSignal[k + 1] = 0;
 					paras[k].threadID = k;
@@ -288,7 +289,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 						processed_reads += read_num;
 						sendWorkSignal ( 11, thrdSignal );
 
-						for ( int k1 = 0; k1 < thrd_num; ++k1 )
+						for ( int k1 = 0; k1 < thrd_num_s; ++k1 )
 						{
 							edge_cnt += edge_cnt_total[k1];
 							edge_cnt_total[k1] = 0;
@@ -429,9 +430,9 @@ int call_pregraph_sparse ( int argc, char ** argv )
 			}
 
 			/*buffers for seperate threads*/
-			path_buffer = ( edge_path_buffer ** ) calloc ( thrd_num, sizeof ( edge_path_buffer ) );
+			path_buffer = ( edge_path_buffer ** ) calloc ( thrd_num_s, sizeof ( edge_path_buffer ) );
 
-			for ( int i = 0; i < thrd_num; i++ )
+			for ( int i = 0; i < thrd_num_s; i++ )
 			{
 				path_buffer[i] = create_edge_path_buffer ( mark_on_edge, s_locks, buff_size, max_path_length );
 			}
@@ -445,7 +446,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 			pthread_mutex_init ( &file_lock, NULL );
 		}
 
-		build_preArc_threaded ( &arc_arr, &v_ht, K_size, cut_off_len, &in_filenames_vt, thrd_num );
+		build_preArc_threaded ( &arc_arr, &v_ht, K_size, cut_off_len, &in_filenames_vt, thrd_num_s );
 
 		if ( solve )
 		{
@@ -462,7 +463,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 			fclose ( mark_fp );
 
 			//output path_buffer
-			for ( int i = 0; i < thrd_num; i++ )
+			for ( int i = 0; i < thrd_num_s; i++ )
 			{
 				output_edge_path_buffer ( path_buffer[i], path_fp );
 			}
@@ -470,7 +471,7 @@ int call_pregraph_sparse ( int argc, char ** argv )
 			fclose ( path_fp );
 
 			//destory buffers ...
-			for ( int i = 0; i < thrd_num; i++ )
+			for ( int i = 0; i < thrd_num_s; i++ )
 			{
 				destory_edge_path_buffer ( path_buffer[i] );
 			}
@@ -540,7 +541,7 @@ static void initenv ( int argc, char ** argv )
 				continue;
 			case 'p':
 				sscanf ( optarg, "%s", temp );
-				thrd_num = atoi ( temp );
+				thrd_num_s = atoi ( temp );
 				continue;
 			case 'm':
 				continue;
@@ -616,7 +617,7 @@ static void parse_args ( vector<string> &in_filenames_vt )
 	}
 
 	fprintf ( stderr, " -r %d", run_mode );
-	fprintf ( stderr, " -p %d", thrd_num );
+	fprintf ( stderr, " -p %d", thrd_num_s );
 	fprintf ( stderr, " -o %s\n\n", graphfile );
 
 	if ( run_mode == 0 ) //build all
@@ -670,7 +671,7 @@ static void parse_args ( vector<string> &in_filenames_vt )
 
 static void display_pregraph_usage()
 {
-	fprintf ( stderr, "Usage: pregraph_sparse -s configFile -K kmer -z genomeSize -o outputGraph [-g maxKmerEdgeLength -d kmerFreqCutoff -e kmerEdgeFreqCutoff -R -r runMode -p n_cpu]\n" );
+	fprintf ( stderr, "Usage: sparse_pregraph -s configFile -K kmer -z genomeSize -o outputGraph [-g maxKmerEdgeLength -d kmerFreqCutoff -e kmerEdgeFreqCutoff -R -r runMode -p n_cpu]\n" );
 	fprintf ( stderr, "  -s <string>     configFile: the config file of solexa reads\n" );
 #ifdef _63MER_
 	fprintf ( stderr, "  -K <int>        kmer(min 13, max 63): kmer size, [23]\n" );
