@@ -30,7 +30,7 @@ static Kmer * kmerBuffer;
 static ubyte8 * hashBanBuffer;
 
 static char * flagBuffer;
-static int buffer_size = 10000000;
+static int buffer_size = 100000000;//2013-5-13
 long long foundcount = 0;
 long long notfoundcount = 0;
 long long newfoundcount = 0;
@@ -1762,9 +1762,9 @@ Return:
 *************************************************/
 static int cmp_seq ( const void * a, const void * b )
 {
-	EDGE * A, *B;
-	A = ( EDGE * ) a;
-	B = ( EDGE * ) b;
+	EDGE_SUB * A, *B;
+	A = ( EDGE_SUB * ) a;
+	B = ( EDGE_SUB * ) b;
 
 	if ( KmerLarger ( vt_array[A->from_vt].kmer, vt_array[B->from_vt].kmer ) )
 	{
@@ -1882,11 +1882,104 @@ Output:
 Return:
     None.
 *************************************************/
+///*
 void sortedge()
 {
 	unsigned int index ;
-	EDGE * sort_edge , * backup_edge ;
-	sort_edge = ( EDGE * ) ckalloc ( sizeof ( EDGE ) * ( num_ed + 1 ) );
+	EDGE_SUB * sort_edge;
+	sort_edge = ( EDGE_SUB * ) ckalloc ( sizeof ( EDGE_SUB ) * ( num_ed + 1 ) );
+	unsigned int i = 1;
+
+	for ( index = 1 ; index <= num_ed ; index ++ )
+	{
+		sort_edge[i].from_vt = edge_array[index].from_vt;
+		sort_edge[i].seq = edge_array[index].seq;
+		sort_edge[i].to_vt = index; // record old id
+		sort_edge[i].length = edge_array[index].length;
+		i++;
+
+		if ( !EdSameAsTwin ( index ) )
+		{
+			index++;
+		}
+	}
+
+	qsort ( & ( sort_edge[1] ), i - 1, sizeof ( sort_edge[1] ), cmp_seq );
+	index_array = ( unsigned int * ) ckalloc ( sizeof ( unsigned int ) * ( num_ed + 1 ) ); // used to record new id
+	unsigned int new_index = 1, old_index;
+
+	for ( index = 1; index <= i - 1; index++ )
+	{
+		old_index = sort_edge[index].to_vt; // old id
+		sort_edge[index].seq = NULL;
+		index_array[old_index] = new_index++;// old id -> new id
+
+		if ( !EdSameAsTwin ( old_index ) )
+		{
+			index_array[old_index + 1] = new_index++; // old id -> new id
+		}
+	}
+
+	bool * copy_array = (bool * ) ckalloc ( sizeof ( bool ) * ( num_ed + 1 ) );
+	EDGE *old_edge = ( EDGE * ) ckalloc ( sizeof ( EDGE ) );
+	EDGE *new_edge = ( EDGE * ) ckalloc ( sizeof ( EDGE ) );
+	unsigned int next_index;
+	for ( index = 1; index <= num_ed; index++ )
+	{
+		if(!copy_array[index])
+		{
+			next_index = index;
+			new_index = index_array[next_index];
+			if(!copy_array[next_index])// && next_index != new_index
+			{
+				if(copy_array[new_index])
+				{
+					fprintf(stderr, "Copy error: never reach here.");
+				}
+				copy_array[next_index] = 1;
+				if(next_index != new_index)
+				{
+					copyOneEdge (old_edge, &(edge_array[new_index]));
+					copyOneEdge ( & ( edge_array[new_index] ), & ( edge_array[next_index] ) );
+				}
+				updateArcToEd ( new_index );
+
+				next_index = new_index;
+				new_index = index_array[next_index];
+				while(!copy_array[next_index])
+				{
+					if(next_index == new_index)
+					{
+						fprintf(stderr, "Index error: never reach here.");
+					}
+					copy_array[next_index] = 1;
+					copyOneEdge (new_edge, &(edge_array[new_index]));
+					copyOneEdge ( & ( edge_array[new_index] ), old_edge);
+					updateArcToEd ( new_index );
+					copyOneEdge (old_edge, new_edge);
+
+					next_index = new_index;
+					new_index = index_array[next_index];
+				}
+			}
+		}
+	}
+
+	free (copy_array);
+	free (old_edge);
+	free (new_edge);
+	free ( index_array );
+	free ( sort_edge );
+	fprintf(stderr, "%d edge(s) sorted.\n", num_ed);
+}
+//*/
+/*
+void sortedge()
+{
+	unsigned int index ;
+	EDGE * backup_edge ;
+	EDGE_SUB * sort_edge;
+	sort_edge = ( EDGE_SUB * ) ckalloc ( sizeof ( EDGE_SUB ) * ( num_ed + 1 ) );
 	backup_edge = ( EDGE * ) ckalloc ( sizeof ( EDGE ) * ( num_ed + 1 ) );
 	unsigned int i = 1;
 
@@ -1932,8 +2025,9 @@ void sortedge()
 	free ( index_array );
 	free ( sort_edge );
 	free ( backup_edge );
+	fprintf(stderr, "%d edge(s) sorted.\n", num_ed);
 }
-
+*/
 /*************************************************
 Function:
     delete0Edge
@@ -2172,7 +2266,8 @@ ARC * sort_arc ( ARC * list )
 	if ( !list )
 		{ return list; }
 
-	ARC * head = ( ARC * ) malloc ( sizeof ( ARC ) );
+//	ARC * head = ( ARC * ) malloc ( sizeof ( ARC ) );
+	ARC * head = ( ARC * ) ckalloc ( sizeof ( ARC ));
 	head->next = list;
 	list->prev = head;
 	ARC * curr = list;
@@ -2239,6 +2334,7 @@ void freshArc()
 
 		edge_array[i].arcs = sort_arc ( edge_array[i].arcs );
 	}
+	fprintf(stderr, "Arcs sorted.\n");
 }
 
 /*************************************************
