@@ -490,6 +490,7 @@ boolean prlRead2HashTable ( char * libfile, char * outfile )
 							if ( start1 >= offset1 )
 							{
 								start1 = 0;
+								offset1 = 0;
 								flag1 = AIORead ( &aio1, &offset1, readBuffer1, cach1, &rt1, lib_array[libNo].curr_type );
 							}
 
@@ -503,6 +504,7 @@ boolean prlRead2HashTable ( char * libfile, char * outfile )
 						if ( start1 >= offset1 )
 						{
 							start1 = 0;
+							offset1 = 0;
 							flag1 = AIORead ( &aio1, &offset1, readBuffer1, cach1, &rt1, lib_array[libNo].curr_type );
 						}
 
@@ -536,6 +538,7 @@ boolean prlRead2HashTable ( char * libfile, char * outfile )
 							if ( start2 >= offset2 )
 							{
 								start2 = 0;
+								offset2 = 0;
 								flag2 = AIORead ( &aio2, &offset2, readBuffer2, cach2, &rt2, lib_array[libNo].curr_type );
 							}
 
@@ -552,6 +555,7 @@ boolean prlRead2HashTable ( char * libfile, char * outfile )
 						if ( start2 >= offset2 )
 						{
 							start2 = 0;
+							offset2 = 0;
 							flag2 = AIORead ( &aio2, &offset2, readBuffer2, cach2, &rt2, lib_array[libNo].curr_type );
 						}
 
@@ -567,6 +571,10 @@ boolean prlRead2HashTable ( char * libfile, char * outfile )
 					}
 				}
 			}
+			else
+			{
+				fprintf(stderr, "Error: aio_read error.\n");
+			}
 		}
 		//read single fasta, single fastq and PE fasta in one file
 		else
@@ -795,7 +803,10 @@ int AIORead ( struct aiocb * mycb, int * offset, char * buf, char * cach, int *
 					*rt = aio_read ( mycb );
 					return 1;
 				}
-
+				else
+				{
+					fprintf(stderr, "Error: aio_return error.\n");
+				}
 				/*else
 				   {
 				   char *temp = (char *)((*mycb).aio_buf);
@@ -807,6 +818,10 @@ int AIORead ( struct aiocb * mycb, int * offset, char * buf, char * cach, int *
 			}
 		}
 	}
+	else
+	{
+		fprintf(stderr, "Error: (*rt != 0) in AIORead.\n");
+	}
 
 	return 0;
 }
