@@ -785,16 +785,19 @@ void Read2edge ( char * libfile, char * graph, int maxk )
 	file_type = ( int * ) ckalloc ( file_num * sizeof ( int ) );
 	file_maxReadLen = ( int * ) ckalloc ( file_num * sizeof ( int ) );
 	index = 0;
+	//2013-5-14
+	int maxReadLenLocal = 0;
 
 	for ( m = 0; m < num_libs; m++ )
 	{
 		if ( lib_array[m].asm_flag != 1 && lib_array[m].asm_flag != 3 )
 			{ continue; }
 
+		//2013-5-14
 		if ( lib_array[m].rd_len_cutoff > 0 )
-			{ maxReadLen = lib_array[m].rd_len_cutoff < maxReadLen4all ? lib_array[m].rd_len_cutoff : maxReadLen4all; }
+			{ maxReadLenLocal = lib_array[m].rd_len_cutoff < maxReadLen4all ? lib_array[m].rd_len_cutoff : maxReadLen4all; }
 		else
-			{ maxReadLen = maxReadLen4all; }
+			{ maxReadLenLocal = maxReadLen4all; }
 
 		//fa1 fa2
 		for ( n = 0; n < lib_array[m].num_a1_file; n++ )
@@ -802,19 +805,19 @@ void Read2edge ( char * libfile, char * graph, int maxk )
 			if ( strlen ( lib_array[m].a1_fname[n] ) > 3 && strcmp ( lib_array[m].a1_fname[n] + strlen ( lib_array[m].a1_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a1_fname[n];
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a2_fname[n];
 			}
 			else
 			{
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a1_fname[n];
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a2_fname[n];
 			}
 		}
@@ -825,19 +828,19 @@ void Read2edge ( char * libfile, char * graph, int maxk )
 			if ( strlen ( lib_array[m].q1_fname[n] ) > 3 && strcmp ( lib_array[m].q1_fname[n] + strlen ( lib_array[m].q1_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 4;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q1_fname[n];
 				file_type[index] = 4;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q2_fname[n];
 			}
 			else
 			{
 				file_type[index] = 2;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q1_fname[n];
 				file_type[index] = 2;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q2_fname[n];
 			}
 		}
@@ -848,13 +851,13 @@ void Read2edge ( char * libfile, char * graph, int maxk )
 			if ( strlen ( lib_array[m].p_fname[n] ) > 3 && strcmp ( lib_array[m].p_fname[n] + strlen ( lib_array[m].p_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].p_fname[n];
 			}
 			else
 			{
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].p_fname[n];
 			}
 		}
@@ -865,13 +868,13 @@ void Read2edge ( char * libfile, char * graph, int maxk )
 			if ( strlen ( lib_array[m].s_a_fname[n] ) > 3 && strcmp ( lib_array[m].s_a_fname[n] + strlen ( lib_array[m].s_a_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_a_fname[n];
 			}
 			else
 			{
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_a_fname[n];
 			}
 		}
@@ -882,13 +885,13 @@ void Read2edge ( char * libfile, char * graph, int maxk )
 			if ( strlen ( lib_array[m].s_q_fname[n] ) > 3 && strcmp ( lib_array[m].s_q_fname[n] + strlen ( lib_array[m].s_q_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 4;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_q_fname[n];
 			}
 			else
 			{
 				file_type[index] = 2;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_q_fname[n];
 			}
 		}
@@ -1255,6 +1258,8 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 	file_type = ( int * ) ckalloc ( file_num * sizeof ( int ) );
 	file_maxReadLen = ( int * ) ckalloc ( file_num * sizeof ( int ) );
 	index = 0;
+	//2013-5-14
+	int maxReadLenLocal = 0;
 
 	for ( m = 0; m < num_libs; m++ )
 	{
@@ -1262,9 +1267,9 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 			{ continue; }
 
 		if ( lib_array[m].rd_len_cutoff > 0 )
-			{ maxReadLen = lib_array[m].rd_len_cutoff < maxReadLen4all ? lib_array[m].rd_len_cutoff : maxReadLen4all; }
+			{ maxReadLenLocal = lib_array[m].rd_len_cutoff < maxReadLen4all ? lib_array[m].rd_len_cutoff : maxReadLen4all; }
 		else
-			{ maxReadLen = maxReadLen4all; }
+			{ maxReadLenLocal = maxReadLen4all; }
 
 		//fa1 fa2
 		for ( n = 0; n < lib_array[m].num_a1_file; n++ )
@@ -1272,19 +1277,19 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 			if ( strlen ( lib_array[m].a1_fname[n] ) > 3 && strcmp ( lib_array[m].a1_fname[n] + strlen ( lib_array[m].a1_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a1_fname[n];
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a2_fname[n];
 			}
 			else
 			{
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a1_fname[n];
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].a2_fname[n];
 			}
 		}
@@ -1295,19 +1300,19 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 			if ( strlen ( lib_array[m].q1_fname[n] ) > 3 && strcmp ( lib_array[m].q1_fname[n] + strlen ( lib_array[m].q1_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 4;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q1_fname[n];
 				file_type[index] = 4;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q2_fname[n];
 			}
 			else
 			{
 				file_type[index] = 2;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q1_fname[n];
 				file_type[index] = 2;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].q2_fname[n];
 			}
 		}
@@ -1318,13 +1323,13 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 			if ( strlen ( lib_array[m].p_fname[n] ) > 3 && strcmp ( lib_array[m].p_fname[n] + strlen ( lib_array[m].p_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].p_fname[n];
 			}
 			else
 			{
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].p_fname[n];
 			}
 		}
@@ -1335,13 +1340,13 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 			if ( strlen ( lib_array[m].s_a_fname[n] ) > 3 && strcmp ( lib_array[m].s_a_fname[n] + strlen ( lib_array[m].s_a_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 3;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_a_fname[n];
 			}
 			else
 			{
 				file_type[index] = 1;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_a_fname[n];
 			}
 		}
@@ -1352,13 +1357,13 @@ void Read2edge2 ( char * libfile, char * graph, int lastTime, int maxk )
 			if ( strlen ( lib_array[m].s_q_fname[n] ) > 3 && strcmp ( lib_array[m].s_q_fname[n] + strlen ( lib_array[m].s_q_fname[n] ) - 3, ".gz" ) == 0 )
 			{
 				file_type[index] = 4;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_q_fname[n];
 			}
 			else
 			{
 				file_type[index] = 2;
-				file_maxReadLen[index] = maxReadLen;
+				file_maxReadLen[index] = maxReadLenLocal;
 				file_Name[index++] = lib_array[m].s_q_fname[n];
 			}
 		}
