@@ -958,7 +958,8 @@ boolean read1seqInLib ( char * src_seq, char * src_name, int * len_seq, int * li
 	if ( ( ( lib_array[i].curr_type != 4 ) && !lib_array[i].fp1 ) // file1 does not exist
 	        || ( ( lib_array[i].curr_type == 4 ) && ( lib_array[i].fp3 == NULL ) ) //file3 does not exist
 	        || ( ( lib_array[i].curr_type == 4 ) && readstate < 0 ) //file3 reaches end
-	        || ( ( lib_array[i].curr_type == 1 || lib_array[i].curr_type == 2 ) && feof ( lib_array[i].fp1 ) && feof ( lib_array[i].fp2 ) ) //f1&f2 reaches end
+	        || ( ( lib_array[i].curr_type == 1 ) && feof ( lib_array[i].fp1 ) && feof ( lib_array[i].fp2 ) ) //f1 && f2 reach end
+		|| ( ( lib_array[i].curr_type == 2 ) && ( feof ( lib_array[i].fp1 ) || feof ( lib_array[i].fp2 ) )) //f1||f2 reaches end
 	        || ( ( lib_array[i].curr_type != 1 && lib_array[i].curr_type != 2 ) && ( lib_array[i].curr_type != 4 ) && feof ( lib_array[i].fp1 ) ) ) // file1 reaches end and not type1 type2 and not type6
 	{
 		if ( lib_array[i].curr_type == 4 )
@@ -971,10 +972,23 @@ boolean read1seqInLib ( char * src_seq, char * src_name, int * len_seq, int * li
 		else
 		{
 			if ( lib_array[i].fp1 && feof ( lib_array[i].fp1 ) )
-				{ closeFp1InLab ( i ); }
+			{ 
+				closeFp1InLab ( i );
 
-			if ( lib_array[i].fp2 && feof ( lib_array[i].fp2 ) )
-				{ closeFp2InLab ( i ); }
+				if ( lib_array[i].fp2 )
+				{
+					closeFp2InLab ( i );
+				}
+			}
+			else if ( lib_array[i].fp2 && feof ( lib_array[i].fp2 ) )
+			{
+				closeFp2InLab ( i );
+
+				if ( lib_array[i].fp1 )
+				{
+					closeFp1InLab ( i );
+				}
+			}
 		}
 
 		*libNo = nextValidIndex ( i, pair, asm_ctg );
